package net.greenfieldtech.cloudonixsdk.cloudonixdialer.adapters;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.LinearLayout;
import android.widget.TextView;
import butterknife.BindView;
import butterknife.ButterKnife;
import java.util.ArrayList;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.R;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.models.Contact;

/**
 * Created by alex on 20.04.16.
 */

public class ContactsAdapter extends RecyclerView.Adapter<ContactsAdapter.ViewHolder> implements
    Filterable {

  public static final int RESOURCE = R.layout.list_item_contact;

  private ArrayList<Contact> contacts;
  private ArrayList<Contact> originResults;
  private Context context;
  private Callback callback;

  public ContactsAdapter(Context context, ArrayList<Contact> contacts) {
    this.context = context;
    this.contacts = contacts;
  }

  @Override
  public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
    View view = LayoutInflater.from(parent.getContext()).inflate(RESOURCE, parent, false);
    return new ViewHolder(view);
  }

  @Override
  public void onBindViewHolder(final ContactsAdapter.ViewHolder holder, final int position) {
    final Contact item = contacts.get(position);

    holder.tvContactName.setText(item.getName());
    holder.root.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View v) {
        if (callback != null) {
          callback.onContactClick(item);
        }
      }
    });
  }

  public void addItems(ArrayList<Contact> additional) {
    contacts.addAll(additional);
    notifyDataSetChanged();
  }

  public ArrayList<Contact> getAllItems() {
    return contacts;
  }

  @Override
  public int getItemCount() {
    return contacts.size();
  }

  public void setCallback(Callback callback) {
    this.callback = callback;
  }

  @Override
  public Filter getFilter() {

    Filter filter = new Filter() {

      @Override
      protected void publishResults(CharSequence constraint, FilterResults filterResults) {
        contacts.clear();
        contacts.addAll((ArrayList<Contact>) filterResults.values);
        notifyDataSetChanged();
      }

      @Override
      protected FilterResults performFiltering(CharSequence constraint) {

        FilterResults filteredResults = new FilterResults();
        ArrayList<Contact> filteredList = new ArrayList<>();

        if (originResults == null || originResults.isEmpty()) {
          originResults = new ArrayList<>(contacts);
        }

        String query = constraint.toString().toLowerCase();

        if (TextUtils.isEmpty(query)) {
          filteredResults.count = originResults.size();
          filteredResults.values = originResults;
        } else {
          for (Contact contact : originResults) {
            if (contact.getName().toLowerCase().startsWith(query)) {
              filteredList.add(contact);
            }
          }
          filteredResults.count = filteredList.size();
          filteredResults.values = filteredList;
        }
        return filteredResults;
      }
    };

    return filter;
  }

  public interface Callback {

    void onContactClick(Contact contact);
  }

  static class ViewHolder extends RecyclerView.ViewHolder {

    @BindView(R.id.item_root)
    LinearLayout root;
    @BindView(R.id.tv_contact_name)
    TextView tvContactName;

    public ViewHolder(View view) {
      super(view);
      ButterKnife.bind(this, view);
    }
  }

}