package net.greenfieldtech.cloudonixsdk.cloudonixdialer.fragments;

import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.support.annotation.Nullable;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import butterknife.BindView;
import butterknife.OnClick;
import butterknife.OnTextChanged;
import java.util.ArrayList;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.R;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.activities.ContactInfoActivity;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.adapters.ContactsAdapter;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.models.Contact;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.views.DividerItemDecoration;

/**
 * Created by alex on 20.04.16.
 */

public class ContactsFragment extends BaseFragment {

  @BindView(R.id.root)
  LinearLayout root;
  @BindView(R.id.recycler_contacts)
  RecyclerView recyclerContacts;
  @BindView(R.id.edt_search)
  EditText edtSearch;
  @BindView(R.id.action_add_contact)
  ImageView ivAddContact;
  @BindView(R.id.action_clear_query)
  ImageView ivClearQuery;

  private LinearLayoutManager layoutManager;
  private ContactsAdapter adapter;

  @Override
  public int getLayoutResource() {
    return R.layout.fragment_contacts;
  }

  @Override
  public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
    super.onViewCreated(view, savedInstanceState);

    layoutManager = new LinearLayoutManager(getActivity());
    recyclerContacts.setLayoutManager(layoutManager);
    recyclerContacts.addItemDecoration(
        new DividerItemDecoration(getActivity(), DividerItemDecoration.LIST_VERTICAL));

    adapter = new ContactsAdapter(getActivity(), getContacts());
    adapter.setCallback(callback);
    recyclerContacts.setAdapter(adapter);
  }

  private ArrayList<Contact> getContacts() {
    ArrayList<Contact> contacts = new ArrayList<>();

    try {
      Cursor phones = getActivity().getContentResolver()
          .query(ContactsContract.CommonDataKinds.Phone.CONTENT_URI, null, null, null, null);
      while (phones.moveToNext()) {
        String name = phones
            .getString(phones.getColumnIndex(ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME));
        String phoneNumber = phones
            .getString(phones.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER));
        int id = phones
            .getInt(phones.getColumnIndex(ContactsContract.CommonDataKinds.Phone.CONTACT_ID));
        contacts.add(new Contact(id, name, phoneNumber));
      }
      phones.close();
    } catch (Exception e) {
      e.printStackTrace();
    }

    return contacts;
  }

  @OnTextChanged(R.id.edt_search)
  void onTextChanged(CharSequence text) {
    if (TextUtils.isEmpty(text)) {
      queryMode(false);
    } else {
      queryMode(true);
    }
    adapter.getFilter().filter(text);
  }

  @Override
  public void onResume() {
    super.onResume();

    adapter = new ContactsAdapter(getActivity(), getContacts());
    adapter.setCallback(callback);
    recyclerContacts.setAdapter(adapter);
  }

  private ContactsAdapter.Callback callback = new ContactsAdapter.Callback() {

    @Override
    public void onContactClick(Contact contact) {
      Intent intent = new Intent(getActivity(), ContactInfoActivity.class);
      intent.putExtra(ContactInfoActivity.CONTACT_NAME, contact.getName());
      intent.putExtra(ContactInfoActivity.CONTACT_NUMBER, contact.getNumber());
      startActivity(intent);
    }

  };

  @OnClick(R.id.action_add_contact)
  public void addContact() {
    Intent intent = new Intent(Intent.ACTION_INSERT, ContactsContract.Contacts.CONTENT_URI);
    startActivity(intent);
  }

  @OnClick(R.id.action_clear_query)
  public void clearQuery() {
    edtSearch.setText("");
  }

  private void queryMode(boolean isQuery) {
    if (isQuery) {
      ivAddContact.setVisibility(View.GONE);
      ivClearQuery.setVisibility(View.VISIBLE);
    } else {
      ivAddContact.setVisibility(View.VISIBLE);
      ivClearQuery.setVisibility(View.GONE);
    }
  }

}
